pub struct SpawnOpts {
pub cwd: String,
pub cols: u16,
pub rows: u16,
pub env: Vec<(String, String)>,
}Fields
cwd: Stringcols: u16Desired terminal columns (passed as layout intent; actual pane size is managed by the terminal proxy anchor).
rows: u16Desired terminal rows (passed as layout intent; actual pane size is managed by the terminal proxy anchor).
env: Vec<(String, String)>Trait Implementations